pub enum HelpTopic {
General,
Size,
Px,
}Expand description
The help topics that can be requested from the server
Variants
General
Help about the general pixelflut protocol and links to further topics
Size
Help about the SIZE command
Px
Help about the PX command (both set and get variants)